@@ -86,7 +86,7 @@
 #define KWAYLANDSERVER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWAYLANDSERVER_NO_DEPRECATED
-#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51502
+#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51600
 #endif
 #ifdef KWAYLANDSERVER_NO_DEPRECATED_WARNINGS
 #  define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0x51502
+#    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0x51600
 #  endif
 #endif
 
@@ -142,5 +142,12 @@
 #define KWAYLANDSERVER_DEPRECATED_VERSION_5(minor, text)      KWAYLANDSERVER_DEPRECATED_VERSION_5_##minor(text)
 #define KWAYLANDSERVER_DEPRECATED_VERSION(major, minor, text) KWAYLANDSERVER_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KWAYLANDSERVER_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWAYLANDSERVER_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KWAYLANDSERVER_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KWAYLANDSERVER_DEPRECATED_VERSION(major, minor, text)
+#  define KWAYLANDSERVER_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWAYLANDSERVER_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KWAYLANDSERVER_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KWAYLANDSERVER_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KWAYLANDSERVER_EXPORT_H */
